@@ -1,4 +1,12 @@
-getContrasts <- function(model, sets = NULL, nSets = 1, ...){
+getContrasts <- function(model, sets = NULL,
+                         nSets = 1,
+                         dispersion = NULL,
+                         use.eliminate = TRUE,
+                         ...){
+    result.as.list <- {
+        (is.null(sets) && (nSets > 1)) ||
+        (!is.null(sets) && is.list(sets))
+    }
     coefs <- coef(model)
     l <- length(coefs)
     of.interest <- ofInterest(model)
@@ -14,7 +22,7 @@ getContrasts <- function(model, sets = NULL, nSets = 1, ...){
                 stop("model has no parameters of interest")
             of.interest <- (model$eliminate + 1):l
         }
-        sets <- relimp:::pickFrom(coefNames[of.interest], nSets,...)
+        sets <- relimp:::pickFrom(coefNames[of.interest], nSets, ...)
     }
     if (!is.list(sets)) sets <- list(sets)
     setLengths <- sapply(sets, length)
@@ -25,7 +33,6 @@ getContrasts <- function(model, sets = NULL, nSets = 1, ...){
     if (is.list(sets)) sets <- sets[setLengths > 1.5]
     if (any(setLengths < 1.5)) warning(
             "Sets with fewer than 2 parameters were dropped,")
-    nSets <- length(sets)
     sets <- lapply(sets, function(x){
         if (is.numeric(x)) x <- coefNames[x]
         contr <- contr.sum(factor(x))
@@ -41,7 +48,9 @@ getContrasts <- function(model, sets = NULL, nSets = 1, ...){
         temp[id, 2:ncol(temp)] <- x$contr
         colnames(temp) <- x$coefs
         temp})
-    lapply(coefMatrix, function(x)
+    Vcov <-  vcov(model, dispersion = dispersion,
+                  use.eliminate = use.eliminate)
+    result <- lapply(coefMatrix, function(x)
        {
         iden <- checkEstimable(model, x)
         if (any(!na.omit(iden))) {
@@ -51,12 +60,12 @@ getContrasts <- function(model, sets = NULL, nSets = 1, ...){
         }
         not.unestimable <- iden | is.na(iden)
         result <- se(model, x[, not.unestimable, drop = FALSE],
-           checkEstimability = FALSE)
+           checkEstimability = FALSE, Vcov = Vcov)
         relerrs <- NULL
         V <- NULL
         if (any(not.unestimable)){
             estimable.names <- names(not.unestimable)[not.unestimable]
-            V <- vcov(model)[estimable.names, estimable.names, drop = FALSE]
+            V <- Vcov[estimable.names, estimable.names, drop = FALSE]
         }
         if (sum(not.unestimable) > 2) {
             QVs <- qvcalc:::qvcalc(V)
@@ -75,4 +84,5 @@ getContrasts <- function(model, sets = NULL, nSets = 1, ...){
                )
     }
            )
+    if (result.as.list) result else result[[1]]
 }
